# Generated from 'TextEdit.h'

teJustLeft = 0
teJustCenter = 1
teJustRight = -1
teForceLeft = -2
teFlushDefault = 0
teCenter = 1
teFlushRight = -1
teFlushLeft = -2
fontBit = 0
faceBit = 1
sizeBit = 2
clrBit = 3
addSizeBit = 4
toggleBit = 5
doFont = 1
doFace = 2
doSize = 4
doColor = 8
doAll = 15
addSize = 16
doToggle = 32
EOLHook = 0
DRAWHook = 4
WIDTHHook = 8
HITTESTHook = 12
nWIDTHHook = 24
TextWidthHook = 28
intEOLHook = 0
intDrawHook = 1
intWidthHook = 2
intHitTestHook = 3
intNWidthHook = 6
intTextWidthHook = 7
intInlineInputTSMTEPreUpdateHook = 8
intInlineInputTSMTEPostUpdateHook = 9
teFAutoScroll = 0
teFTextBuffering = 1
teFOutlineHilite = 2
teFInlineInput = 3
teFUseWhiteBackground = 4
teFUseInlineInput = 5
teFInlineInputAutoScroll = 6
teFIdleWithEventLoopTimer = 7
teBitClear = 0
teBitSet = 1
teBitTest = -1
teWordSelect = 4
teWordDrag = 8
teFromFind = 12
teFromRecal = 16
teFind = 0
teHighlight = 1
teDraw = -1
teCaret = -2
teFUseTextServices = 4
